@@ -1,25 +1,21 @@
 
 from .workbook import open_workbook
 from .workbook import close_workbook
-from .workbook import new_excel_instance
-from .workbook import any_excel_instance
-from .workbook import empty_excel_instance
+from .workbook import new_excel_application
+from .workbook import any_excel_application
+from .workbook import empty_excel_application
 from .workbook import all_excel_instances
 
-from .worksheet import get_worksheet
-
 from .excel_address import col_letter_offset
 from .excel_address import col_letter
 from .excel_address import col_number
 
-
 __all__ = ['open_workbook',
            'close_workbook',
-           'new_excel_instance',
-           'any_excel_instance',
-           'empty_excel_instance',
+           'new_excel_application',
+           'any_excel_application',
+           'empty_excel_application',
            'all_excel_instances',
-           'get_worksheet',
            'col_letter_offset',
            'col_letter',
            'col_number']
